package com.solution.algo.mapper;

import java.util.List;
import com.solution.algo.domain.SysAlgoConfig;

/**
 * 动态规则配置Mapper接口
 * 
 * @author zouju
 * @date 2026-02-05
 */
public interface SysAlgoConfigMapper 
{
    /**
     * 查询动态规则配置
     * 
     * @param id 动态规则配置主键
     * @return 动态规则配置
     */
    public SysAlgoConfig selectSysAlgoConfigById(Long id);

    /**
     * 查询动态规则配置列表
     * 
     * @param sysAlgoConfig 动态规则配置
     * @return 动态规则配置集合
     */
    public List<SysAlgoConfig> selectSysAlgoConfigList(SysAlgoConfig sysAlgoConfig);

    /**
     * 新增动态规则配置
     * 
     * @param sysAlgoConfig 动态规则配置
     * @return 结果
     */
    public int insertSysAlgoConfig(SysAlgoConfig sysAlgoConfig);

    /**
     * 修改动态规则配置
     * 
     * @param sysAlgoConfig 动态规则配置
     * @return 结果
     */
    public int updateSysAlgoConfig(SysAlgoConfig sysAlgoConfig);

    /**
     * 删除动态规则配置
     * 
     * @param id 动态规则配置主键
     * @return 结果
     */
    public int deleteSysAlgoConfigById(Long id);

    /**
     * 批量删除动态规则配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSysAlgoConfigByIds(Long[] ids);
}
